/* ExactTreeGenerator.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.conjecture.engine.apengine;

/**
 * Tree generator that generates trees with exactly the given amount of
 * unary and binary operators.
 */
public class ExactTreeGenerator<T extends BinaryTree> extends TreeGenerator<T> {
    
    //
    public ExactTreeGenerator(int unaryOperators, int binaryOperators, TreeFactory<T> treeFactory) {
        super(unaryOperators, binaryOperators, treeFactory);
    }
    
    //
    private boolean hasMore() {
        return !stateStack.empty();
    }
    
    /**
     * Return the next {@link LabeledBinaryTree} or {@code null} when no more tree is available.
     */
    public T nextTree() {
        
        completeWorkingTree = false;
        
        while(hasMore() && (!completeWorkingTree)) {
            extend();
        }
        
        if (completeWorkingTree)
            return workingTree;
        else
            return null;
        
    }
    
    protected void pushNextOperatorCount() {
        // just one combination of unary and binary operators
    }

}
