/* AbstractOperator.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.expr;

import java.util.HashMap;
import java.util.Map;

/**
 * Common super class of all (standard) operators.
 */
abstract class AbstractOperator implements Operator {
    
    /**
     * Maps names to operators.
     */
    static final Map<String,Operator> map
            = new HashMap<String,Operator> ();
    
    //
    private final String name;
    
    public String getName () {
        return name;
    }
    
    //
    private final int numberOfArguments;

    public int getNumberOfArguments() {
        return numberOfArguments;
    }
    
    //
    private final int strength;

    public int getStrength() {
        return strength;
    }
    
    //
    private final String id;
    
    public String getId() {
        return id;
    }
    
    /**
     * Return an operator with the given name and number of
     * arguments.
     */
    protected AbstractOperator (String id, String name, int numberOfArguments, int strength) {
        this.id = id;
        this.name = name;
        this.numberOfArguments = numberOfArguments;
        this.strength = strength;
        map.put (id, this);
    }
    
}
