/* AbstractGraphGenerator.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.generators.graphs;

import java.text.MessageFormat;

import org.grinvin.factories.AbstractNamedFactory;

/**
 * Common superclass of various graph generator classes. Provides support for
 * internationalization and some helper methods.
 */
public abstract class AbstractGraphGenerator extends AbstractNamedFactory implements GraphGenerator {
    
    /**
     * Default constructor.
     */
    public AbstractGraphGenerator() {
        super ("generator");
    }
    
    //
    public String getInstanceId () {
        return getId() + getParametersAsString();
    }
    
    /**
     * Get the name for the instance from the internal factory properties.
     */
    protected String getInstanceName () {
        String nameFormat = factoryProps.getProperty("instance.name");
        return MessageFormat.format(nameFormat, (Object[])valueStrings);
    }
    
    /**
     * get the description for the instance from the internal factory properties.
     */
    protected String getInstanceDescription () {
        String descFormat = factoryProps.getProperty("instance.description");
        return  MessageFormat.format(descFormat, (Object[])valueStrings);
    }
}
