/* GraphModel.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.graphs;

/**
 * A {@link GraphView} which at the same time functions as a model 
 * in a model-view-controller triple. A {@link GraphListener} may
 * register itself with this model to be informed about various changes:
 * <ul>
 * <li>Addition or removal of an edge or vertex.</li>
 * <li>Changes in annotation of a vertex or an edge.</li>
 * <li>Bulk changes to the graph.</li>
 * </ul><p>
 */
public interface GraphModel extends GraphView {
    
    /**
     * Register a graph listener with this model.
     */
    public void addGraphListener (GraphListener l);
    
    /**
     * Unregister a previously registered graph listener.
     */
    public void removeGraphListener (GraphListener l);
}
