/* GraphBundleWithModels.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.gred;

import org.grinvin.graphs.DefaultAnnotationModel;
import org.grinvin.graphs.DefaultEmbeddingModel;
import org.grinvin.graphs.DefaultGraphBundle;
import org.grinvin.graphs.DefaultGraphModel;

/**
 * Implementation of {@link org.grinvin.graphs.GraphBundle} which uses a
 * {@link DefaultGraphModel} to represent a graph and uses a 
 * {@link DefaultEmbeddingModel} to represent an embedding.
 */
public class GraphBundleWithModels extends DefaultGraphBundle {
    
    // implements GraphBundleView
    public DefaultEmbeddingModel getEmbedding (int index) {
        return (DefaultEmbeddingModel)embeddings.get(index);
    }

    /**
     * {@inheritDoc} 
     * <p>This implementation creates an embedding of type {@link DefaultEmbeddingModel}.
     */
    public DefaultEmbeddingModel createEmbedding () {
        DefaultEmbeddingModel embedded = new DefaultEmbeddingModel (graph, 0);
        embeddings.add (embedded);
        return embedded;
    }
    
    // implements GraphBundleView
    public DefaultEmbeddingModel getEmbedding () {
        return getEmbedding (0);
    }
    
    /**
     * {@inheritDoc} 
     * <p>This implementation creates a graph of type {@link DefaultGraphModel}.
     */
    public DefaultGraphModel createGraph () {
        DefaultGraphModel model = new DefaultGraphModel ();
        this.graph = model;
        return model;
    }
    
    // implements GraphBundleView
    public DefaultGraphModel getGraph () {
        return (DefaultGraphModel)graph;
    }
    
    /**
     * {@inheritDoc} 
     * <p>This implementation creates an annotation of type {@link DefaultAnnotationModel}.
     */
    public DefaultAnnotationModel createAnnotation() {
        DefaultAnnotationModel annotation = new DefaultAnnotationModel(graph);
        annotations.add(annotation);
        return annotation;
    }
    
    // implements GraphBundleView
    public DefaultAnnotationModel getAnnotation() {
        return getAnnotation(0);
    }
    
    // implements GraphBundleView
    public DefaultAnnotationModel getAnnotation(int index) {
        return (DefaultAnnotationModel)annotations.get(index);
    }

}
