/* MultilineToolTip.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.gui;

import javax.swing.JToolTip;
import java.awt.Color;

/**
 * Multiline tooltip that supports automatic wrapping and color changes in some situations.
 */
public class MultilineToolTip extends JToolTip {

    protected int tipWidth = Integer.MAX_VALUE;
    protected Color background;
    protected Color darkerBackground;
    
    public MultilineToolTip() {
        updateUI();
    }
    
    public MultilineToolTip(int width) {
        this.tipWidth = width;
        updateUI();
        this.background = getBackground();
        this.darkerBackground = this.background.darker();
    }
    
    public void updateUI() {
        setUI(MultilineToolTipUI.createUI(this));
    }
    
    public void setTipWidth(int width) {
        if(width>0)
            this.tipWidth = width;
    }
    
    public int getTipWidth() {
        return tipWidth;
    }
    
    public void setExtraInfo(boolean aFlag){
        if(aFlag)
            setBackground(this.darkerBackground);
        else
            setBackground(this.background);
    }
}
