/* Invariant.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.invariants;

/**
 * Represents the mathematical concept of graph invariant, like 'diameter',
 * 'average degree', 'largest eigenvalue'... Is uniquely identified
 * by an identifier string. Mapping between identifier strings and 
 * invariant instances is done by the invariant manager.
 * @see InvariantManager
 */
public interface Invariant {
    
   /**
     * Universally unique identifier for this invariant.
     */
    public String getId();
    
    /**
     * Returns the localized name of the invariant.
     */
    public String getName();

    /**
     * Returns the class to which all values of this invariant belong.
     * This class must be an extension of {@link InvariantValue}.
     */
    public Class<? extends InvariantValue> getType ();
    
}
