/* InvariantType.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.invariants;

import org.grinvin.invariants.values.BooleanValueDelegate;
import org.grinvin.invariants.values.IntegerMatrixValueDelegate;
import org.grinvin.invariants.values.IntegerValueDelegate;
import org.grinvin.invariants.values.ListOfIntegersValueDelegate;
import org.grinvin.invariants.values.ListOfRealsValueDelegate;
import org.grinvin.invariants.values.RealValueDelegate;
import org.grinvin.invariants.values.UnavailableValueDelegate;

/**
 * Helper enum which handles invariant types.
 */
public enum InvariantType {
    
    INTEGER("integer", IntegerValueDelegate.getInstance()),
    REAL("real", RealValueDelegate.getInstance()),
    BOOLEAN("boolean", BooleanValueDelegate.getInstance()),
    LISTOFINTEGERS("listOfIntegers", ListOfIntegersValueDelegate.getInstance()),
    LISTOFREALS("listOfReals", ListOfRealsValueDelegate.getInstance()),
    INTEGERMATRIX("integerMatrix", IntegerMatrixValueDelegate.getInstance()),
    UNAVAILABLE("unavailable", UnavailableValueDelegate.getInstance());
    
    //
    public String name;
    
    //
    public InvariantValueDelegate<? extends InvariantValue> delegate;
    
    //
    InvariantType(String name, InvariantValueDelegate<? extends InvariantValue> delegate) {
        this.name = name;
        this.delegate = delegate;
    }
    
    //
    public InvariantValueDelegate<? extends InvariantValue> getDelegate() {
        return delegate;
    }
    
    //
    public String getTypeName() {
        return name;
    }
    
    //
    @Override
    public String toString() {
        return getTypeName();
    }
    
    //
    public static InvariantType getEnumForType(String type) {
        for(InvariantType invariantType : InvariantType.values()) {
            if(invariantType.getTypeName().equals(type))
                return invariantType;
        }
        return null;
    }
}
