/* InvariantValueDelegate.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.invariants;

import javax.swing.JComponent;
import javax.swing.JLabel;

import org.grinvin.io.IOFormatException;
import org.grinvin.list.graphs.GraphListElement;

import org.jdom.Element;

/**
 *
 */
public interface InvariantValueDelegate<T extends InvariantValue> {
    
    public Element toElement(T value);
    
    public T load(Element element) throws
        IOFormatException, UnknownInvariantException, UnknownInvariantTypeException;

    public T load_1_0(Element element) throws
        IOFormatException, UnknownInvariantException, UnknownInvariantTypeException;
    
    public Class<T> getType();
    
    public void initLabel(JLabel label, T value);
    
    /**
     * Show a 'details window' for the given invariant value component.
     *
     * @param value The invariant value
     * @param element Graph list element for which this invariant value
     * was computed
     * @param component Component which invoked this method
     * @param x X coordinate of mouse pointer when this method was invoked
     * @param y Y coordinate of mouse pointer when this method was invoked
     */
    public void showDetails(T value, GraphListElement element, JComponent component, int x, int y);

    /**
     * Is it possible to obtain a 'details window' for this component?
     */
    public boolean hasDetails(T value);
    
}
