/* BooleanValue.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.invariants.values;

import java.util.ResourceBundle;

import org.grinvin.invariants.Invariant;
import org.grinvin.invariants.InvariantComputer;
import org.grinvin.invariants.InvariantType;

/**
 * Invariant type which allows boolean values.
 * Identified by the string <code>boolean</code>.
 */
public class BooleanValue extends AbstractInvariantValue {
    
    //
    private boolean value;
    
    /**
     * Create an object of this type with the given boolean value.
     */
    public BooleanValue (boolean value, InvariantComputer computer) {
        super (InvariantType.BOOLEAN, computer);
        this.value = value;
    }
    
    BooleanValue(boolean value, Invariant invariant, String computerId, String computerVersion) {
        super(InvariantType.BOOLEAN, invariant, computerId, computerVersion);
        this.value = value;
    }
    
    public boolean getValue() {
        return value;
    }
    
    //
    public String toText () {
        ResourceBundle rbundle = ResourceBundle.getBundle ("org.grinvin.invariants.resources");
        return rbundle.getString(Boolean.toString(value));
    }
    
}
