/* GraphBundlePreview.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.list.actions;


import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.File;
import javax.swing.JFileChooser;

import org.grinvin.gui.components.NamedGraphComponent;
import org.grinvin.list.graphs.GraphListElementManager;

/**
 * Generate a preview of the graphbundle. Set this component as an accessory of a <code>JFileChooser</code>.
 */
public class GraphBundlePreview extends NamedGraphComponent implements PropertyChangeListener {
    
    public GraphBundlePreview(JFileChooser fileChooser) {
        fileChooser.addPropertyChangeListener(this);
    }

    public void propertyChange(PropertyChangeEvent e) {
        String changedProperty = e.getPropertyName();

        if (JFileChooser.DIRECTORY_CHANGED_PROPERTY.equals(changedProperty)) {
            setElement(null);
        } else if (JFileChooser.SELECTED_FILE_CHANGED_PROPERTY.equals(changedProperty)) {
            if(e.getNewValue()!=null && ((File)e.getNewValue()).getName().toLowerCase().endsWith(".gph")) {
                setElement(GraphListElementManager.getInstance().getGraphListElement(((File)e.getNewValue()).toURI()));
            } else {
                setElement(null);
            }
        }
    }
}
