/* IntegerList.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.params;

/**
 * List of integers
 */
public class IntegerList {
    
    private int[] list;
    
    public IntegerList(){
        
    }
    
    public IntegerList(int[] array){
        list = new int[array.length];
        System.arraycopy(array, 0, list, 0, array.length);
    }
    
    public IntegerList(String string){
        String[] parts = string.split(",");
        list = new int[parts.length];
        try {
            for(int i = 0; i<parts.length; i++)
                list[i]=Integer.parseInt(parts[i].trim());
        } catch (NumberFormatException ex) {
            list = null;
        }
    }
    
    public int getLength(){
        return list != null ? list.length : -1;
    }
    
    public int getIntegerAt(int index) throws ArrayIndexOutOfBoundsException, NullPointerException {
        return list[index];
    }
    
    public String toString(){
        if(list==null || list.length==0)
            return "";
        StringBuffer s = new StringBuffer(2*list.length);
        s.append(list[0]);
        for(int i=1; i<list.length; i++){
            s.append("," + list[i]);
        }
        return s.toString();
    }
}
